@@ -6,7 +6,6 @@ import pykka
 from mopidy import backend
 
 from .library import SoundCloudLibraryProvider
-from .playlists import SoundCloudPlaylistsProvider
 from .soundcloud import SoundCloudClient
 
 logger = logging.getLogger(__name__)
@@ -17,10 +16,9 @@ class SoundCloudBackend(pykka.ThreadingActor, backend.Backend):
     def __init__(self, config, audio):
         super(SoundCloudBackend, self).__init__()
         self.config = config
-        self.sc_api = SoundCloudClient(config['soundcloud']['auth_token'])
+        self.remote = SoundCloudClient(config['soundcloud'])
         self.library = SoundCloudLibraryProvider(backend=self)
         self.playback = SoundCloudPlaybackProvider(audio=audio, backend=self)
-        self.playlists = SoundCloudPlaylistsProvider(backend=self)
 
         self.uri_schemes = ['soundcloud']
 
@@ -28,6 +26,6 @@ class SoundCloudBackend(pykka.ThreadingActor, backend.Backend):
 class SoundCloudPlaybackProvider(backend.PlaybackProvider):
 
     def play(self, track):
-        id = self.backend.sc_api.parse_track_uri(track)
-        track = self.backend.sc_api.get_track(id, True)
+        track_id = self.backend.remote.parse_track_uri(track)
+        track = self.backend.remote.get_track(track_id, True)
         return super(SoundCloudPlaybackProvider, self).play(track)
